==> thunderbird-51.0a1.en-US.win64.xpcshell.tests.zip: xpcshell/tests/toolkit/mozapps/update/tests/data/xpcshellConstantsPP.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* Preprocessed constants used by xpcshell tests */

const INSTALL_LOCALE = "en-US";
const MOZ_APP_NAME = "thunderbird";
const BIN_SUFFIX = ".exe";

// MOZ_APP_VENDOR is optional.
//@line 13 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const MOZ_APP_VENDOR = "";
//@line 17 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

// MOZ_APP_BASENAME is not optional for tests.
const MOZ_APP_BASENAME = "Thunderbird";
const APP_BIN_SUFFIX = ".exe";

const APP_INFO_NAME = "XPCShell";
const APP_INFO_VENDOR = "Mozilla";

//@line 26 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_WIN = true;
//@line 30 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 34 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_MACOSX = false;
//@line 36 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 40 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_UNIX = false;
//@line 42 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 46 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_ANDROID = false;
//@line 48 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 52 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_TOOLKIT_GONK = false;
//@line 54 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 58 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_MAR_CHECKS_ENABLED = false;
//@line 60 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 64 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
 const IS_AUTHENTICODE_CHECK_ENABLED = true;

==> thunderbird-59.0a1.en-US.win64.xpcshell.tests.zip: xpcshell/tests/toolkit/mozapps/update/tests/data/xpcshellConstantsPP.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

/* Preprocessed constants used by xpcshell tests */

const INSTALL_LOCALE = "en-US";
const MOZ_APP_NAME = "thunderbird";
const BIN_SUFFIX = ".exe";

// MOZ_APP_VENDOR is optional.
//@line 13 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const MOZ_APP_VENDOR = "";
//@line 17 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

// MOZ_APP_BASENAME is not optional for tests.
const MOZ_APP_BASENAME = "Thunderbird";
const APP_BIN_SUFFIX = ".exe";

const APP_INFO_NAME = "XPCShell";
const APP_INFO_VENDOR = "Mozilla";

//@line 26 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_WIN = true;
//@line 30 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 34 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_MACOSX = false;
//@line 36 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 40 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const IS_UNIX = false;
//@line 42 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 46 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
const MOZ_VERIFY_MAR_SIGNATURE = false;
//@line 48 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"

//@line 52 "c:\builds\moz2_slave\tb-c-cen-w64-ntly-000000000000\build\mozilla\toolkit\mozapps\update\tests\data\xpcshellConstantsPP.js"
 const IS_AUTHENTICODE_CHECK_ENABLED = true;
